<?php

/**
 * @file bookmarks_public.theme.inc
 * Themable functions required to render user profile bookmarks
 */

/**
 * Theme each menu item, adding important CSS data
 *
 * @ingroup themable
 */
function theme_bookmarks_public_item($item, $id) {
  static $expanded = NULL;
  if (!is_array($expanded)) {
    if (!isset($_COOKIE['dhtml_menu'])) {
      $_COOKIE['dhtml_menu'] = '';
    }
    $expanded = explode(',', $_COOKIE['dhtml_menu']);
  }

  // Unset hidden sub-items. This avoids items with empty, all-hidden sub-menus.
  if (!empty($item['below'])) {
    foreach ($item['below'] as $index => $leaf) {
      if ($leaf['link']['hidden']) {
        unset($item['below'][$index]);
      }
    }
  }

  // Check if the menu item has a submenu
  // If no, create a normal menu item
  // If yes, create the submenu too
  if (empty($item['below'])) {
    $output = '  <li class="leaf" id="menu-leaf'. $id .'">' . theme('menu_item_link', $item['link']);
    if (!empty($item['link']['options']['attributes']['title'])) {
      $output .= '<div class="bookmark_desc">'. $item['link']['options']['attributes']['title'] .'</div>';
    }
    $output .= "</li>\n";
    return $output;
  }
  else {
    $type = isset($item['link']['type']) ? $item['link']['type'] : NULL;
    if ($item['link']['in_active_trail'] || $item['link']['expanded'] || in_array("sub$id", $expanded)) {
      $state = 'expanded';
      $display = '';
    }
    else {
      $state = 'collapsed';
      $display = ' style="display: none;"';
    } 

    $output = "<li class=\"menutitle $state\" id=\"menu-sub$id\">";
    $output .= theme('menu_item_link', $item['link']);
    if (!empty($item['link']['options']['attributes']['title'])) {
      $output .= '<div class="bookmark_desc">'. $item['link']['options']['attributes']['title'] .'</div>';
    }
    $output .= "<div class=\"submenu\" id=\"sub$id\"$display>";
    $output .= theme('bookmarks_public_tree', $item['below'], $item['link'], $id);
    $output .= '</div></li>';
    return $output;
  }
}

/**
 * Theme each menu, adding important CSS data
 *
 * @ingroup themable
 */
function theme_bookmarks_public_tree($tree, $parent = NULL, $pid = NULL) {
  // If no further items, return blank
  if (empty($tree)) {
    return '';
  }

  $add_links = _dhtml_get_add_links();
  $output = '';
  if ($parent && isset($add_links[$parent['link_path']])) {
    $duplication = $parent;
    if ($add_links[$parent['link_path']] !== TRUE) {
      $duplication['title'] = $add_links[$parent['link_path']];
    }
    $output .= '<li class="leaf" id="menu-leaf'. $pid .'">'. theme('menu_item_link', $duplication) ."</li>\n";
  }

  $class = 'menu';
  if ($parent == NULL) {
    $class .= ' menu-root';

    // Add the proper JS file
    drupal_add_js(drupal_get_path('module', 'dhtml_menu') .'/dhtml_menu.js');

    // If the effect is on, tell it to JS
    if ($effects = variable_get('dhtml_menu_use_effects', 0)) {
      drupal_add_js(array('dhtmlMenu_useEffects' => 1), 'setting');
    }
    // If Hide Siblings is on, tell it to JS
    if ($effects = variable_get('dhtml_menu_hide_siblings', 0)) {
      drupal_add_js(array('dhtmlMenu_hideSiblings' => 1), 'setting');
    }
  }

  foreach ($tree as $pid => $item) {
    // hidden sub-items are removed already; this line takes care of root items.
    if ($item['link']['hidden']) {
      continue;
    }

    // pid is going to be a DOM identifier, and can't have some characters
    $pid = ereg_replace('[^A-Za-z0-9]', '', $pid);

    $output .= theme('bookmarks_public_item', $item, $pid);
  }

  return "\n<ul class=\"$class\">\n". $output ."\n</ul>\n";
}
